@@ -52,11 +52,13 @@ package com.openexchange.drive.events.apn.internal;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.TimeUnit;
+import com.openexchange.drive.events.DriveContentChange;
 import com.openexchange.drive.events.DriveEvent;
 import com.openexchange.drive.events.apn2.util.ApnsHttp2Notification;
 import com.openexchange.drive.events.apn2.util.ApnsHttp2Options;
 import com.openexchange.drive.events.apn2.util.SubscriptionDeliveryTask;
 import com.openexchange.drive.events.subscribe.Subscription;
+import com.openexchange.drive.events.subscribe.SubscriptionMode;
 import com.openexchange.server.ServiceLookup;
 import com.turo.pushy.apns.DeliveryPriority;
 import com.turo.pushy.apns.PushType;
@@ -89,12 +91,26 @@ public class APNSubscriptionDeliveryTask extends SubscriptionDeliveryTask {
         if (null != pushTokenReference && subscription.matches(pushTokenReference)) {
             return null;
         }
+        if (null == options) {
+            return null;
+        }
         ApnsHttp2Notification.Builder builder = new ApnsHttp2Notification.Builder(subscription.getToken(), options.getTopic())
             .withCustomField("root", subscription.getRootFolderID())
             .withCustomField("action", "sync")
             .withContentAvailable(true)
             .withExpiration(TimeUnit.DAYS.toMillis(1L))
         ;
+        if (event.isContentChangesOnly() && SubscriptionMode.SEPARATE.equals(subscription.getMode())) {
+            List<String> paths = new ArrayList<String>();
+            for (DriveContentChange contentChange : event.getContentChanges()) {
+                if (contentChange.isSubfolderOf(subscription.getRootFolderID())) {
+                    paths.add(contentChange.getPath(subscription.getRootFolderID()));
+                }
+            }
+            if (false == paths.isEmpty()) {
+                builder.withCustomField("paths", paths);
+            }
+        }
         builder.withPriority(DeliveryPriority.CONSERVE_POWER);
         builder.withPushType(PushType.BACKGROUND);
         return builder.build();
