@@ -54,7 +54,6 @@ import java.util.Set;
 import com.openexchange.drive.DriveAction;
 import com.openexchange.drive.DriveVersion;
 
-
 /**
  * {@link DriveEvent}
  *
@@ -64,11 +63,15 @@ public interface DriveEvent {
 
     /**
      * Gets the consecutive actions to be executed by the client, based on the supplied root folder identifier(s).
+     * <p/>
+     * In case concrete directory versions are included in the actions, a <i>synthetic</i> random checksum may get applied as the actual
+     * value is unknown at this stage.
      *
      * @param rootFolderIDs The root folder IDs the client is interested in.
+     * @param useContentChanges <code>true</code> to prefer separate SYNC actions for content changes where possible, <code>false</code>, otherwise
      * @return The client actions
      */
-    List<DriveAction<? extends DriveVersion>> getActions(List<String> rootFolderIDs);
+    List<DriveAction<? extends DriveVersion>> getActions(List<String> rootFolderIDs, boolean useContentChanges);
 
     /**
      * Gets the context ID.
@@ -84,6 +87,20 @@ public interface DriveEvent {
      */
     Set<String> getFolderIDs();
 
+    /**
+     * Gets all tracked content changes within specific folders.
+     *
+     * @return The folder content changes, or an empty collection if there were none
+     */
+    List<DriveContentChange> getContentChanges();
+
+    /**
+     * Gets a value indicating whether this drive event is about folder content changes only or not.
+     *
+     * @return <code>true</code> if there are content changes only, <code>false</code>, otherwise
+     */
+    boolean isContentChangesOnly();
+
     /**
      * Gets a value indicating whether this event is originated from a remote backend node or not.
      *
