@@ -80,29 +80,31 @@ public class DirectoryChecksumsAddUsedColumnTask extends UpdateTaskAdapter {
     @Override
     public void perform(PerformParameters params) throws OXException {
         Connection connection = params.getConnection();
-        boolean rollback = false;
+        int rollback = 0;
         try {
             if (Tools.columnExists(connection, "directoryChecksums", "used")) {
                 return;
             }
 
             connection.setAutoCommit(false);
-            rollback = true;
+            rollback = 1;
 
             deleteDirectoryChecksums(connection);
             Tools.addColumns(connection, "directoryChecksums", new Column("used", "BIGINT(20) NOT NULL DEFAULT 0"));
 
             connection.commit();
-            rollback = false;
+            rollback = 2;
         } catch (SQLException e) {
             throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } catch (RuntimeException e) {
             throw UpdateExceptionCodes.OTHER_PROBLEM.create(e, e.getMessage());
         } finally {
-            if (rollback) {
-                rollback(connection);
+            if (rollback > 0) {
+                if (rollback == 1) {
+                    rollback(connection);
+                }
+                autocommit(connection);
             }
-            autocommit(connection);
         }
     }
 
