@@ -57,7 +57,6 @@ import com.openexchange.drive.FileVersion;
 import com.openexchange.drive.impl.DriveUtils;
 import com.openexchange.drive.impl.checksum.ChecksumProvider;
 import com.openexchange.drive.impl.checksum.FileChecksum;
-import com.openexchange.drive.impl.management.DriveConfig;
 import com.openexchange.drive.impl.metadata.DriveMetadata;
 import com.openexchange.drive.impl.storage.StorageOperation;
 import com.openexchange.exception.OXException;
@@ -135,7 +134,7 @@ public class DownloadHelper {
                     throw DriveExceptionCodes.FILE_NOT_FOUND.create(fileVersion.getName(), path);
                 }
                 long contentLength = 0 < offset || 0 < length && length != file.getFileSize() ? -1L : file.getFileSize();
-                boolean throttled = 0 < DriveConfig.getInstance().getMaxBandwidth() || 0 < DriveConfig.getInstance().getMaxBandwidthPerClient();
+                boolean throttled = 0 < session.getConfig().getMaxBandwidth() || 0 < session.getConfig().getMaxBandwidthPerClient();
                 return new DriveFileHolder(session, inputStream, fileVersion.getName(), file.getFileMIMEType(), contentLength, throttled);
             }
         });
