@@ -171,9 +171,7 @@ public class DriveServiceImpl implements DriveService {
     @Override
     public SyncResult<DirectoryVersion> syncFolders(DriveSession session, List<DirectoryVersion> originalVersions, List<DirectoryVersion> clientVersions) throws OXException {
         return syncFolders(session, originalVersions, clientVersions, (SyncSession syncSession) -> {
-            ServerSession serverSession = syncSession.getServerSession();
-            int maxDirectories = DriveConfig.getInstance().getMaxDirectories(serverSession.getContextId(), serverSession.getUserId());
-            return syncSession.getServerDirectories(maxDirectories);
+            return syncSession.getServerDirectories(syncSession.getConfig().getMaxDirectories());
         });
     }
 
@@ -182,20 +180,21 @@ public class DriveServiceImpl implements DriveService {
         /*
          * check (hard) version restrictions
          */
-        if (session.getApiVersion() < DriveConfig.getInstance().getMinApiVersion(serverSession.getContextId(), serverSession.getUserId())) {
+        DriveConfig driveConfig = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId());
+        if (session.getApiVersion() < driveConfig.getMinApiVersion()) {
             return getErrorResult(session, DriveExceptionCodes.CLIENT_OUTDATED.create(), true);
         }
         DriveClientVersion clientVersion = session.getClientVersion();
         if (null != clientVersion) {
-            DriveClientVersion hardVersionLimit = DriveConfig.getInstance().getHardMinimumVersion(session.getClientType(), serverSession);
+            DriveClientVersion hardVersionLimit = driveConfig.getHardMinimumVersion(session.getClientType(), serverSession);
             if (0 > clientVersion.compareTo(hardVersionLimit)) {
                 return getErrorResult(session, DriveExceptionCodes.CLIENT_VERSION_OUTDATED.create(clientVersion, hardVersionLimit), true);
             }
         }
-        if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), session)) {
+        if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), driveConfig)) {
             return getErrorResult(session, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
         }
-        int maxDirectories = DriveConfig.getInstance().getMaxDirectories(serverSession.getContextId(), serverSession.getUserId());
+        int maxDirectories = driveConfig.getMaxDirectories();
         if (-1 != maxDirectories && null != clientVersions && maxDirectories < clientVersions.size()) {
             return getErrorResult(session, DriveExceptionCodes.TOO_MANY_DIRECTORIES.create(I(maxDirectories)), true);
         }
@@ -279,7 +278,7 @@ public class DriveServiceImpl implements DriveService {
              * check (soft) version restrictions
              */
             if (null != clientVersion) {
-                DriveClientVersion softVersionLimit = DriveConfig.getInstance().getSoftMinimumVersion(session.getClientType(), serverSession);
+                DriveClientVersion softVersionLimit = driveConfig.getSoftMinimumVersion(session.getClientType(), serverSession);
                 if (0 > clientVersion.compareTo(softVersionLimit)) {
                     OXException error = DriveExceptionCodes.CLIENT_VERSION_UPDATE_AVAILABLE.create(clientVersion, softVersionLimit);
                     LOG.trace("Client upgrade available for {}", session, error);
@@ -307,12 +306,12 @@ public class DriveServiceImpl implements DriveService {
         long start = System.currentTimeMillis();
         DriveVersionValidator.validateFileVersions(originalVersions);
         DriveVersionValidator.validateFileVersions(clientVersions);
-        ServerSession serverSession = session.getServerSession();
-        int maxFilesPerDirectory = DriveConfig.getInstance().getMaxFilesPerDirectory(serverSession.getContextId(), serverSession.getUserId());
+        DriveConfig driveConfig = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId());
+        int maxFilesPerDirectory = driveConfig.getMaxFilesPerDirectory();
         if (-1 != maxFilesPerDirectory && null != clientVersions && maxFilesPerDirectory < clientVersions.size()) {
             return getErrorResult(session, path, DriveExceptionCodes.TOO_MANY_FILES.create(I(maxFilesPerDirectory), path), true);
         }
-        if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), session)) {
+        if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), driveConfig)) {
             return getErrorResult(session, path, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
         }
         int retryCount = 0;
@@ -490,6 +489,7 @@ public class DriveServiceImpl implements DriveService {
         /*
          * collect settings
          */
+        DriveConfig driveConfig = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId());
         DriveSettings settings = new DriveSettings();
         ServerSession serverSession = session.getServerSession();
         DriveStorage storage = syncSession.getStorage();
@@ -498,16 +498,17 @@ public class DriveServiceImpl implements DriveService {
         settings.setQuota(new DriveQuotaImpl(quota, syncSession.getLinkGenerator().getQuotaLink()));
         settings.setHelpLink(syncSession.getLinkGenerator().getHelpLink());
         settings.setServerVersion(DriveServiceLookup.getService(VersionService.class, true).getVersionString());
-        settings.setMinApiVersion(String.valueOf(DriveConfig.getInstance().getMinApiVersion(serverSession.getContextId(), serverSession.getUserId())));
+        settings.setMinApiVersion(String.valueOf(driveConfig.getMinApiVersion()));
         settings.setSupportedApiVersion(String.valueOf(DriveConstants.SUPPORTED_API_VERSION));
         settings.setMinUploadChunk(Long.valueOf(syncSession.getOptimisticSaveThreshold()));
         settings.setHasTrashFolder(storage.hasTrashFolder());
         settings.setPathToRoot(storage.getInternalPath(session.getRootFolderID()));
+        settings.setMaxConcurrentSyncFiles(driveConfig.getMaxConcurrentSyncFiles());
         /*
          * add any localized folder names (up to a certain depth after which no localized names are expected anymore)
          */
         Map<String, String> localizedFolders = new HashMap<String, String>();
-        int maxDirectories = DriveConfig.getInstance().getMaxDirectories(serverSession.getContextId(), serverSession.getUserId());
+        int maxDirectories = driveConfig.getMaxDirectories();
         Map<String, FileStorageFolder> folders = storage.getFolders(maxDirectories, 2);
         for (Map.Entry<String, FileStorageFolder> entry : folders.entrySet()) {
             String localizedName = entry.getValue().getLocalizedName(session.getLocale());
@@ -686,7 +687,8 @@ public class DriveServiceImpl implements DriveService {
         return Category.CATEGORY_TRY_AGAIN.equals(e.getCategory()) ||
             Category.CATEGORY_CONFLICT.equals(e.getCategory()) ||
             "FLD-0008".equals(e.getErrorCode()) || // 'Folder 123 does not exist in context 1'
-            "DRV-0007".equals(e.getErrorCode()) // The file "123.txt" with checksum "8fc1a2f5e9a2dbd1d5f4f9e330bd1563" was not found at "/"
+            "DRV-0007".equals(e.getErrorCode()) || // The file "123.txt" with checksum "8fc1a2f5e9a2dbd1d5f4f9e330bd1563" was not found at "/"
+            "DRV-0003".equals(e.getErrorCode())    // The file "123.txt" was not found at "/"
         ;
     }
 
