@@ -80,6 +80,7 @@ import com.openexchange.drive.impl.DriveUtils;
 import com.openexchange.drive.impl.checksum.ChecksumProvider;
 import com.openexchange.drive.impl.checksum.DirectoryChecksum;
 import com.openexchange.drive.impl.comparison.ServerDirectoryVersion;
+import com.openexchange.drive.impl.management.DriveConfig;
 import com.openexchange.drive.impl.metadata.DirectoryMetadataParser;
 import com.openexchange.drive.impl.metadata.FileMetadataParser;
 import com.openexchange.drive.impl.metadata.JsonDirectoryMetadata;
@@ -97,7 +98,6 @@ import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.file.storage.FolderPath;
 import com.openexchange.file.storage.OriginAwareFileStorageFolder;
 import com.openexchange.file.storage.composition.FilenameValidationUtils;
-import com.openexchange.file.storage.composition.IDBasedFolderAccess;
 import com.openexchange.folderstorage.FolderResponse;
 import com.openexchange.folderstorage.FolderService;
 import com.openexchange.folderstorage.FolderServiceDecorator;
@@ -162,7 +162,7 @@ public class DriveUtilityImpl implements DriveUtility {
 
     @Override
     public boolean isIgnoredFileName(String fileName, Session session) throws OXException {
-        return DriveUtils.isIgnoredFileName(fileName, session);
+        return DriveUtils.isIgnoredFileName(fileName, new DriveConfig(session.getContextId(), session.getUserId()));
     }
 
     @Override
@@ -405,7 +405,7 @@ public class DriveUtilityImpl implements DriveUtility {
                 if (FilenameValidationUtils.isInvalidFileName(targetName)) {
                     throw DriveExceptionCodes.INVALID_FILENAME.create(targetName);
                 }
-                if (DriveUtils.isIgnoredFileName(session, path, targetName)) {
+                if (DriveUtils.isIgnoredFileName(syncSession, path, targetName)) {
                     throw DriveExceptionCodes.IGNORED_FILENAME.create(targetName);
                 }
                 if (null != syncSession.getStorage().getFileByName(targetPath, targetName, true)) {
@@ -599,13 +599,13 @@ public class DriveUtilityImpl implements DriveUtility {
         JSONObject result = new JSONObject(2);
 
         try {
-            FileStorageFolder[] subfolders = trashContent.getSubfolders();
+            FileStorageFolder[] subfolders = trashContent != null ? trashContent.getSubfolders() : null;
             if (subfolders != null && subfolders.length > 0) {
                 JSONArray folderArray = loadFolders(syncSession, subfolders);
                 result.put(DIRECTORIES, filterUnwantedFields(folderArray));
             }
 
-            SearchIterator<File> files = trashContent.getFiles();
+            SearchIterator<File> files = trashContent != null ? trashContent.getFiles() : null;
             if (files != null) {
                 JSONArray fileArray = loadFiles(syncSession, files);
                 if (fileArray.length() > 0) {
