@@ -56,7 +56,6 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.Semaphore;
 import com.openexchange.drive.impl.internal.DriveServiceLookup;
-import com.openexchange.drive.impl.management.DriveConfig;
 import com.openexchange.exception.OXException;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
@@ -79,15 +78,6 @@ public class DriveTokenBucket implements TokenBucket {
     private final int clientBytesPerSecond;
     private final ScheduledTimerTask bucketFillerTask;
 
-    /**
-     * Initializes a new {@link DriveTokenBucket}.
-     *
-     * @throws OXException
-     */
-    public DriveTokenBucket() throws OXException {
-        this(DriveConfig.getInstance().getMaxBandwidth(), DriveConfig.getInstance().getMaxBandwidthPerClient());
-    }
-
     /**
      * Initializes a new {@link DriveTokenBucket}.
      *
@@ -95,7 +85,7 @@ public class DriveTokenBucket implements TokenBucket {
      * @param clientBytesPerSecond The allowed bytes per second and client, or <code>-1</code> if unlimited
      * @throws OXException
      */
-    public DriveTokenBucket(int overallBytesPerSecond, int clientBytesPerSecond) throws OXException {
+    public DriveTokenBucket(int overallBytesPerSecond, int clientBytesPerSecond) {
         super();
         /*
          * init client / overall bucket semaphores
@@ -155,10 +145,10 @@ public class DriveTokenBucket implements TokenBucket {
         int acquired = 0;
         do {
             int permits = Math.min(count - acquired, maxPermits);
-            System.out.println("acquire: " + permits + "/" + count);
+            LOG.debug("acquire: " + permits + "/" + count);
             semaphore.acquire(permits);
             acquired += permits;
-            System.out.println("acquired: " + acquired + "/" + count);
+            LOG.debug("acquired: " + acquired + "/" + count);
         } while (acquired < count);
     }
 
@@ -177,7 +167,7 @@ public class DriveTokenBucket implements TokenBucket {
         return true;
     }
 
-    private void fillBuckets() {
+    void fillBuckets() {
         /*
          * release permits for overall bucket
          */
