@@ -71,13 +71,11 @@ import com.openexchange.drive.impl.comparison.ThreeWayComparison;
 import com.openexchange.drive.impl.comparison.VersionMapper;
 import com.openexchange.drive.impl.internal.PathNormalizer;
 import com.openexchange.drive.impl.internal.SyncSession;
-import com.openexchange.drive.impl.management.DriveConfig;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.File.Field;
 import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.file.storage.FileStoragePermission;
-import com.openexchange.tools.session.ServerSession;
 
 
 /**
@@ -89,7 +87,7 @@ public class DirectorySynchronizer extends Synchronizer<DirectoryVersion> {
 
     private Map<String, Set<String>> normalizedFilesnamesPerFolder;
 
-    public DirectorySynchronizer(SyncSession session, VersionMapper<DirectoryVersion> mapper) throws OXException {
+    public DirectorySynchronizer(SyncSession session, VersionMapper<DirectoryVersion> mapper) {
         super(session, mapper);
     }
 
@@ -140,8 +138,7 @@ public class DirectorySynchronizer extends Synchronizer<DirectoryVersion> {
 
     @Override
     protected int getMaxActions() {
-        ServerSession serverSession = session.getServerSession();
-        return DriveConfig.getInstance().getMaxDirectoryActions(serverSession.getContextId(), serverSession.getUserId());
+        return session.getConfig().getMaxDirectoryActions();
     }
 
     @Override
@@ -326,12 +323,11 @@ public class DirectorySynchronizer extends Synchronizer<DirectoryVersion> {
                  * same directory version, let client update it's metadata
                  */
                 result.addActionForClient(new AcknowledgeDirectoryAction(comparison.getOriginalVersion(), comparison.getClientVersion(), comparison));
-                if (false == DriveConstants.EMPTY_MD5.equals(comparison.getClientVersion().getChecksum()) &&
-                    Change.NEW.equals(comparison.getClientChange()) && Change.NEW.equals(comparison.getServerChange())) {
+                if (false == DriveConstants.EMPTY_MD5.equals(comparison.getClientVersion().getChecksum())) {
                     /*
-                     * first-time synchronization of identical, but non-empty directory, let client sync directory to acknowledge the contents
+                     * conflicting change of identical, but non-empty directory, let client sync directory to acknowledge the contents
                      */
-                    result.addActionForClient(new SyncDirectoryAction(comparison.getServerVersion(), comparison));
+                    result.addActionForClient(new SyncDirectoryAction(comparison.getClientVersion(), comparison));
                     return 1;
                 } else {
                     return 0;
@@ -386,7 +382,7 @@ public class DirectorySynchronizer extends Synchronizer<DirectoryVersion> {
                 /*
                  * let client synchronize the directory
                  */
-                result.addActionForClient(new SyncDirectoryAction(comparison.getClientVersion(), comparison));
+                result.addActionForClient(new SyncDirectoryAction(comparison.getClientVersion(), comparison, true));
                 return 1;
             } else {
                 OXException e = DriveExceptionCodes.NO_CREATE_DIRECTORY_PERMISSION.create(lastExistingParentVersion.getPath());
