@@ -73,7 +73,6 @@ import com.openexchange.drive.impl.comparison.VersionMapper;
 import com.openexchange.drive.impl.internal.PathNormalizer;
 import com.openexchange.drive.impl.internal.SyncSession;
 import com.openexchange.drive.impl.internal.UploadHelper;
-import com.openexchange.drive.impl.management.DriveConfig;
 import com.openexchange.drive.impl.metadata.DriveMetadata;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.File;
@@ -81,7 +80,6 @@ import com.openexchange.file.storage.FileStorageObjectPermission;
 import com.openexchange.file.storage.FileStoragePermission;
 import com.openexchange.file.storage.composition.FilenameValidationUtils;
 import com.openexchange.file.storage.composition.FolderID;
-import com.openexchange.tools.session.ServerSession;
 import com.openexchange.user.User;
 
 
@@ -98,7 +96,7 @@ public class FileSynchronizer extends Synchronizer<FileVersion> {
     private FileStoragePermission folderPermission;
     private Set<String> normalizedDirectoryNames;
 
-    public FileSynchronizer(SyncSession session, VersionMapper<FileVersion> mapper, String path) throws OXException {
+    public FileSynchronizer(SyncSession session, VersionMapper<FileVersion> mapper, String path) {
         super(session, mapper);
         this.path = path;
     }
@@ -109,12 +107,16 @@ public class FileSynchronizer extends Synchronizer<FileVersion> {
         uploadActions = new ArrayList<UploadFileAction>();
         IntermediateSyncResult<FileVersion> syncResult = super.sync();
         /*
-         * inject upload offsets if needed
+         * inject upload offsets if needed, disable chunked upload if no temporary upload files possible
          */
         if (0 < uploadActions.size()) {
+            boolean noChunks = false == mayCreate() && false == session.getTemp().supported();
             List<FileVersion> versionsToUpload = new ArrayList<FileVersion>(uploadActions.size());
             for (UploadFileAction uploadAction : uploadActions) {
                 versionsToUpload.add(uploadAction.getNewVersion());
+                if (noChunks) {
+                    uploadAction.getParameters().put(DriveAction.PARAMETER_NO_CHUNKS, Boolean.TRUE);
+                }
             }
             List<Long> uploadOffsets = new UploadHelper(session).getUploadOffsets(path, versionsToUpload);
             for (int i = 0; i < uploadOffsets.size(); i++) {
@@ -176,8 +178,7 @@ public class FileSynchronizer extends Synchronizer<FileVersion> {
 
     @Override
     protected int getMaxActions() {
-        ServerSession serverSession = session.getServerSession();
-        return DriveConfig.getInstance().getMaxFileActions(serverSession.getContextId(), serverSession.getUserId());
+        return session.getConfig().getMaxFileActions();
     }
 
     @Override
@@ -343,7 +344,7 @@ public class FileSynchronizer extends Synchronizer<FileVersion> {
                     result.addActionForClient(new ErrorFileAction(null, comparison.getClientVersion(), comparison, path,
                         DriveExceptionCodes.INVALID_FILENAME.create(comparison.getClientVersion().getName()), true));
                     return 1;
-                } else if (DriveUtils.isIgnoredFileName(session.getDriveSession(), path, comparison.getClientVersion().getName())) {
+                } else if (DriveUtils.isIgnoredFileName(session, path, comparison.getClientVersion().getName())) {
                     /*
                      * ignored file, indicate as error with quarantine flag
                      */
