@@ -58,10 +58,10 @@ import com.openexchange.drive.DriveFileField;
 import com.openexchange.drive.DriveMetaMode;
 import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.FilePattern;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.java.Strings;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.user.User;
 
 /**
  * {@link DefaultDriveSession}
@@ -82,6 +82,7 @@ public class DefaultDriveSession implements DriveSession {
     private List<FilePattern> fileExclusions;
     private List<DirectoryPattern> directoryExclusions;
     private String driveMeta;
+    private boolean includeQuota;
 
     /**
      * Initializes a new {@link DefaultDriveSession}.
@@ -158,6 +159,15 @@ public class DefaultDriveSession implements DriveSession {
         this.driveMeta = driveMeta;
     }
 
+    /**
+     * Configures to include current quota and usage in the response or not, when applicable.
+     *
+     * @param includeQuota <code>true</code> if quota information should be included, <code>false</code>, otherwise
+     */
+    public void setIncludeQuota(boolean includeQuota) {
+        this.includeQuota = includeQuota;
+    }
+
     @Override
     public String getRootFolderID() {
         return rootFolderID;
@@ -244,6 +254,11 @@ public class DefaultDriveSession implements DriveSession {
         return useDriveMeta() ? DriveMetaMode.DEFAULT : DriveMetaMode.DISABLED;
     }
 
+    @Override
+    public boolean isIncludeQuota() {
+        return includeQuota;
+    }
+
     @Override
     public String toString() {
         return "DriveSession [sessionID=" + session.getSessionID() + ", rootFolderID=" + rootFolderID + ", contextID=" +
