@@ -70,6 +70,7 @@ public class DriveSettings {
     private int minSearchChars;
     private boolean hasTrashFolder;
     private String pathToRoot;
+    private int maxConcurrentSyncFiles;
 
     /**
      * Initializes a new {@link DriveSettings}.
@@ -276,4 +277,22 @@ public class DriveSettings {
         this.pathToRoot = pathToRoot;
     }
 
+    /**
+     * Gets the maxConcurrentSyncFiles
+     *
+     * @return The maxConcurrentSyncFiles
+     */
+    public int getMaxConcurrentSyncFiles() {
+        return maxConcurrentSyncFiles;
+    }
+
+    /**
+     * Sets the maxConcurrentSyncFiles
+     *
+     * @param maxConcurrentSyncFiles The maxConcurrentSyncFiles to set
+     */
+    public void setMaxConcurrentSyncFiles(int maxConcurrentSyncFiles) {
+        this.maxConcurrentSyncFiles = maxConcurrentSyncFiles;
+    }
+
 }
